@@ -1,7 +1,7 @@
 """Basic support for ZControl® devices equipped with pumps."""
 
 from dataclasses import dataclass
-from enum import StrEnum, auto
+from enum import StrEnum
 
 from .basic import ZControlDevice
 
@@ -17,10 +17,7 @@ class ZControlPumpDevice(ZControlDevice):
         class Type(StrEnum):
             """Defines pump types."""
         
-            DC = auto()
-
-        type: Type | None = None
-        """The pump's type."""
+            DC = "DC"
 
         current: float | None = None
         """The pump's current in amps."""
@@ -34,5 +31,5 @@ class ZControlPumpDevice(ZControlDevice):
         airlock_detected: bool | None = None
         """Whether or not the pump has detected an airlock."""
 
-    pumps: [Pump] = None
-    """The device's pumps."""
+    pumps: dict[Pump.Type: Pump] = None
+    """The device's pumps by type."""
